findviews_to_compare_core detects views on which two arbitrary sets of
tuples are well separated. It produces the same
results as findviews_to_compare, but does not
present them with a Shiny app.
findviews_to_compare_core(group1, group2, data, view_size_max = NULL, clust_method = "complete")nrow(data), which describes the
first group to compare. The value TRUE at position i indicates the
the i-th row of data belongs to the group.TRUE at position i indicates the the i-th row of
data belongs to the group.NULL, findviews uses log2(ncol(data)), rounded upwards and
capped at 5.hclust. Example values are "complete", "single" or
"average".findviews_to_compare_core takes two groups of tuples as
input, and detects views on which the statistical distribution of those two
groups is different. See the documentation of
findviews_to_compare for more details.The difference between findviews_to_compare and
findviews_to_compare_core is that the former presents
its results with a Shiny app, while the latter simply outputs them as R
stuctures.
findviews_to_compare_core(mtcars$mpg >= 20 , mtcars$mpg < 20 , mtcars)
Run the code above in your browser using DataLab