The function findviews_to_predict takes a data set and a target
variable as input. It detects clusters of statistically dependent columns in
the data set - e.g., views - and ranks those groups according to how well
they predict the target variable.To detect the views, findviews_to_predict relies on findviews.
To evaluate their predictive power, it uses the mutual information
between the joint distribution of the columns and that of the target
variable. Internally, findviews_to_predict discretizes all the
continuous variables with equi-width binning.
Note: findviews_to_predict removes the column to be predicted (the
target column) from the dataset before it creates the column groups. Hence,
the views it returns may be different from those return by calling by
findviews directly on the dataset.